@@ -6,9 +6,6 @@ import pvporcupine
 
 from voiceassistant.config import Config
 from voiceassistant.exceptions import ConfigValidationError
-from voiceassistant.interfaces.base import InterfaceIO
-
-from .microphone_stream import MicrophoneStream
 
 
 class KeywordDetector:
@@ -40,8 +37,3 @@ class KeywordDetector:
     def not_detected(self, audio_chunk: bytes) -> bool:
         """Determine if keyword was not detected."""
         return self.process(audio_chunk) < 0
-
-    def wait_untill_detected(self, stream: MicrophoneStream, interface: InterfaceIO) -> None:
-        """Wait till keyword was detected."""
-        while self.not_detected(stream.read()):
-            pass
